<document type=odyssee>
%%with-pdf no-dlp no-wrl
@cite=2
<c><p align=right><a href=@text-paper-odyssee.pdf>PDF</a></p></c>
<so abstract-odyssee>
<include file=@biblio/keys>

@* Introduction

In june 2003, our group was asked to advise on the use
of VR in a theatre production of the Odyssee.
Lacking experience in this field,
we accepted the invitation to participate with some reluctance,
since at the time we didn't have any clue what the VR
for the theatre production should look like.
Nevertheless, we took the invitation as a challenge
and started looking for appropriate hardware,
bothering collegues for information on mixed reality
art productions, and downloading code to explore
software technologies.
Many hurdles ware to be taken.
We had to deal with organizational issues,
such as finding the money for financing the actual production
(which is at the time of writing still an issue),
finding the right people (students, in our case) to select material and
contribute to the code; aesthetic issues, in particular 
to determine which approach to take to reach at an effective solution;
and not in the least technical issues, to realize the 
production on a sufficiently efficient low-cost platform.

:@ structure
In this short paper, we will first briefly describe the Odyssee theatre
production.
Then we will report on how we arrived at our present mixed reality
solution.
And, after a brief characterization of our platform of choice,
we will look at our mixed reality solution in 
somewhat more (technical) detail.
We finish with recapitulating the lessons we learned
from our explorations in mixed reality theatre.


@* Background -- the Odyssee theatre production

The <url href=http://www.odyssee2004.nl>Odyssee</url>.
theatre production was initiated by <url href=http://www.ground-control.org>Ground Control</url>,
as a successor of previously succesful theatrical spectacles,
including an open air performance of <url href=http://www.faust2002.nl>Faust</url>.
In effect, two performances of the Odyssee are planned,
an out-door (external) version, involving real ships
at the shore of a lake, and an in-door (internal) version,
to be played in temporarily empty office buildings.
The in-door version is meant to give
a more psychological rendering of the Odyssee [_Metamorphose],
where the travels of Ulysses are experienced by the audience
as a confrontation with themselves.
Our contribution was asked for the in-door version,
to enhance the experience of the audience with
additional VR.
<lp>
The Odyssee is a wellknown account of the travels of Ulysses
leaving Troje, in 24 episodes ending in his return to Ithaca and 
his reunion with Penelope.
The actual theatre production takes 12 parts which are played 
in 12 successive rooms through which the audience,
subdivided in small groups,
is guided one room after another for about five minutes per room.
Our initial idea was to add information in the form of text and 
images, to direct the interpretation of the audience
towards a particular perspective.
In that beginning stage, somewhat optimistically, we
planned to offer multiple perspectives to each
participant, in an individualized manner,
dependent on the actual focus of attention of the individual participant.


@* Initial ideas -- VR and augmented reality

Our first problem was to find suitable hardware,
that is see-through goggles.
Searching the Internet gave us the name of a relatively nearby 
company, <url href=http://www.cybermind.nl>Cyber Mind NL</url>,
that specialized in entertainment VR solutions.
Both price-wise and in terms of functionality semi-transparent
see-through glasses appeared to be no option,
so instead we chose for simple LCD-projection goggles
with a (head-mounted) low-resolution camera.
This solution also meant that we did not need
expensive head orientation tracking equipment,
since we could, in principle, determine focus using 
captured image analysis solutions such as provided by the <url href=http://www.hitl.washington.edu/research/shared_space/download>AR Toolkit</url>.
Moreover, captured video feed ensured the 
continuity and reactiveness needed for
a true (first-person perspective) VR experience.
<lp>
<url href=http://www.se.rit.edu/~jrv/research/ar>Augmented or mixed reality</url>
is an interesting area of research
with many potential applications.
However, in the course of the project we dropped our ambition
to develop personalized presentations using
image analysis, since we felt that the technology
for doing this in a mixed reality theatre setting is simply not ripe,
and instead we concentrated on using the captured
video feed as the driver for text and image presentation.
In addition, we developed image manipulation techniques
to transform the (projection of the) captured video,
to obtain more implicit effects, as to avoid the explicit
semantic overload resulting from the exclusive use of text
and images.


@* Technological constraints -- the DirectX platform

After a few experiments with the AR Toolkit, it soon appeared
that the frame rate would not be sufficient, on the type
of machines our budget would allow for.
Moreover, reading the AR Toolkit mailing list,
marker tracking in a theatrical context
seemed to be more or less unfeasible.
So, we shifted focus to the
<url href=http://www.microsoft.com/windows/directx>DirectX SDK 9</url>,
both for video capture and projection in 3D.
The DirectX toolkit is a surprisingly functional, and very rich
technology for multimedia applications,
supporting streamed video, including live capture,
3D object rendering and precise synchronisation
between multimedia content-related events.
At that time, and still at the time of writing,
our own <em><url href=http://www.intelligent-multimedia.net>intelligent multimedia technology</url></em>
was no option, since it does not allow for
using live video capture and is also lacking in down-to-the-millisecond
synchronisation.
<lp>
After exploring texture mapping images copied
from the incoming captured video stream,
we decided to use the
VMR-9 <em><url href=http://www.cs.vu.nl/~eliens/media/resources-directx.html>video mixing renderer</url></em>
introduced in DirectX 9, 
that allows for allocating 3D objects as its rendering surface,
thus avoiding the overhead of
explicit copies taken from a video processing stream
running in a separate thread.
Although flexible and efficient,
DirectX is a low-level toolkit,
which means that we had to create our own
facilities for processing a scenegraph,
world and viewpoint transformations, and, even more importantly,
structuring our mixed reality presentations in time.

@* Structuring time -- maintaining 'see-through' aesthetics

One of the problems we encountered in discussing what
we conveniently may call the VR with the producer of
the Odyssee theatre performance was the high expectancy
people have of VR, no doubt inspired by movies
as the Matrix and the like.
In mixed reality applications, manipulating persons,
warps in space, and basically any intensive image
analysis or image manipulation is simply not possible
in real time.
Moreover, there is a disturbing tendency
with the layman to strive for semantic overload
by overlaying the scene with multiple images and lines of text,
thus obscuring the reality captured by the camera
and literally blocking the participants view
and awareness of the scene.
Basically, as a guideline, we tend to strive for
70\% visibility of the scene,
20\% image or projection transformations
and only 10\% of information in the form of text and images.
<lp>
The total duration of our presentation is only 2 minutes,
or 118 seconds to be precise.
We made a subdivision in 4 scenes, with transitions
inbetween, hierarchically ordered in a tree-like structure.
Initially, we abstracted from the actual duration,
by taking only the fraction of the time passed
(in relation to the total duration) as an indication
for which scene to display.
However, when the development reached its final
stages, we introduced actual durations that allowed
us to time the sequence of scenes to the tenth
of a second.
In addition, we used multiple layers of presentation,
roughly subdivided in background captured image,
the transformed captured image projected on 3D objects,
and, finally, pictures and text.
These layers are rendered on top of eachother,
triggered in a time-based fashion, semi-independent
of one another.
The frame rate varies between 20 and 30, dependent
on the number of images simultaneously used
for texturing.
Our final mixed reality theatre application may be considered
a prototype,
awaiting to be put to the test by the audience.


@* Lessons learned -- our explorations revisited

Altogether, the development of the mixed reality
theatre application has been quite an experience,
in multiple ways.
<lp>
Not in the least it has been (and still is) a challenge
to explain the possibilities of mixed reality
applications to the layman, that do not take
the abstractions we use in our daily academic
life for granted.
<lp>
To be frank, it also has opened our eyes to what some
consider 'politically incorrect' technology,
in other words Microsoft DirectX,
originally developed as game technology,
and no doubt a rich toolbox for real life multimedia
applications.
<lp>
Reinventing the wheel is not as simple as it seems.
Nevertheless, developing scenegraph processing facilities
and the appropriate timing mechanisms for controlling
the mixed reality presentation was, apart from
being a rekindling of basic skills, a learnful experience.
<lp>
Finally, even before putting the application
to the test,
considering the aesthetics of mixed reality
theatre productions,
it may be called an eye-opener to realize
how important reality is,
and how meaningless explicit semantics
(in the form of text and images) may become.
Rather, we see our explorations as an incentive
to further explore more implicit (graphical)
modifications of the captured scene to convey meaning.


@* Conclusions

We have described, in a somewhat anecdotical fashion,
our experiences in developing a mixed reality
application for the Odyssee theatre production,
to enhance the participants experience of the performance.
Our explorations involved, among others,
to deal with expectancies of VR,
aesthetic issues,
not to mention production schedules,
cooperation, 
financial issues, but above all it meant
setting the first steps in developing technology for
mixed reality theatre.

:@ Acknowledgements
We thank Bart Gloudemans and Rutger van Dijk
(both students at the Vrije Universiteit)
for their
practical work on the project, as well as their 
general contribution to the final contents of the work.
Furthermore, we are grateful to Bert Barten 
for engaging us in the Odyssee theatre project.

<include file=@biblio/refs>
</document>
